==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/CustomerRental.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}RentalDetails"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCUSTOMERRENTALREQUEST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}IssueDetails" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}ReturnDetails" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}InvoicingDetails" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentalid",
    "rentalDetails",
    "iscustomerrentalrequest",
    "issueDetails",
    "returnDetails",
    "invoicingDetails",
    "standardUserDefinedFields",
    "userdefinedarea"
})
@XmlRootElement(name = "CustomerRental")
public class CustomerRental {

    @XmlElement(name = "CUSTOMERRENTALID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALID_Type customerrentalid;
    @XmlElement(name = "RentalDetails", required = true)
    protected RentalDetails rentalDetails;
    @XmlElement(name = "ISCUSTOMERRENTALREQUEST", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscustomerrentalrequest;
    @XmlElement(name = "IssueDetails")
    protected IssueDetails issueDetails;
    @XmlElement(name = "ReturnDetails")
    protected ReturnDetails returnDetails;
    @XmlElement(name = "InvoicingDetails")
    protected InvoicingDetails invoicingDetails;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the customerrentalid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public CUSTOMERRENTALID_Type getCUSTOMERRENTALID() {
        return customerrentalid;
    }

    /**
     * Sets the value of the customerrentalid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public void setCUSTOMERRENTALID(CUSTOMERRENTALID_Type value) {
        this.customerrentalid = value;
    }

    /**
     * Gets the value of the rentalDetails property.
     * 
     * @return
     *     possible object is
     *     {@link RentalDetails }
     *     
     */
    public RentalDetails getRentalDetails() {
        return rentalDetails;
    }

    /**
     * Sets the value of the rentalDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link RentalDetails }
     *     
     */
    public void setRentalDetails(RentalDetails value) {
        this.rentalDetails = value;
    }

    /**
     * Gets the value of the iscustomerrentalrequest property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCUSTOMERRENTALREQUEST() {
        return iscustomerrentalrequest;
    }

    /**
     * Sets the value of the iscustomerrentalrequest property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCUSTOMERRENTALREQUEST(String value) {
        this.iscustomerrentalrequest = value;
    }

    /**
     * Gets the value of the issueDetails property.
     * 
     * @return
     *     possible object is
     *     {@link IssueDetails }
     *     
     */
    public IssueDetails getIssueDetails() {
        return issueDetails;
    }

    /**
     * Sets the value of the issueDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueDetails }
     *     
     */
    public void setIssueDetails(IssueDetails value) {
        this.issueDetails = value;
    }

    /**
     * Gets the value of the returnDetails property.
     * 
     * @return
     *     possible object is
     *     {@link ReturnDetails }
     *     
     */
    public ReturnDetails getReturnDetails() {
        return returnDetails;
    }

    /**
     * Sets the value of the returnDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReturnDetails }
     *     
     */
    public void setReturnDetails(ReturnDetails value) {
        this.returnDetails = value;
    }

    /**
     * Gets the value of the invoicingDetails property.
     * 
     * @return
     *     possible object is
     *     {@link InvoicingDetails }
     *     
     */
    public InvoicingDetails getInvoicingDetails() {
        return invoicingDetails;
    }

    /**
     * Sets the value of the invoicingDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link InvoicingDetails }
     *     
     */
    public void setInvoicingDetails(InvoicingDetails value) {
        this.invoicingDetails = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/CustomerRental.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CUSTOMERRENTALID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERRENTALID"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}RentalDetails"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISCUSTOMERRENTALREQUEST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}IssueDetails" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}ReturnDetails" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_entities/CustomerRental_001}InvoicingDetails" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customerrentalid",
    "rentalDetails",
    "iscustomerrentalrequest",
    "issueDetails",
    "returnDetails",
    "invoicingDetails",
    "standardUserDefinedFields",
    "userdefinedarea"
})
@XmlRootElement(name = "CustomerRental")
public class CustomerRental {

    @XmlElement(name = "CUSTOMERRENTALID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected CUSTOMERRENTALID_Type customerrentalid;
    @XmlElement(name = "RentalDetails", required = true)
    protected RentalDetails rentalDetails;
    @XmlElement(name = "ISCUSTOMERRENTALREQUEST", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscustomerrentalrequest;
    @XmlElement(name = "IssueDetails")
    protected IssueDetails issueDetails;
    @XmlElement(name = "ReturnDetails")
    protected ReturnDetails returnDetails;
    @XmlElement(name = "InvoicingDetails")
    protected InvoicingDetails invoicingDetails;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the customerrentalid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public CUSTOMERRENTALID_Type getCUSTOMERRENTALID() {
        return customerrentalid;
    }

    /**
     * Sets the value of the customerrentalid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERRENTALID_Type }
     *     
     */
    public void setCUSTOMERRENTALID(CUSTOMERRENTALID_Type value) {
        this.customerrentalid = value;
    }

    /**
     * Gets the value of the rentalDetails property.
     * 
     * @return
     *     possible object is
     *     {@link RentalDetails }
     *     
     */
    public RentalDetails getRentalDetails() {
        return rentalDetails;
    }

    /**
     * Sets the value of the rentalDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link RentalDetails }
     *     
     */
    public void setRentalDetails(RentalDetails value) {
        this.rentalDetails = value;
    }

    /**
     * Gets the value of the iscustomerrentalrequest property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCUSTOMERRENTALREQUEST() {
        return iscustomerrentalrequest;
    }

    /**
     * Sets the value of the iscustomerrentalrequest property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCUSTOMERRENTALREQUEST(String value) {
        this.iscustomerrentalrequest = value;
    }

    /**
     * Gets the value of the issueDetails property.
     * 
     * @return
     *     possible object is
     *     {@link IssueDetails }
     *     
     */
    public IssueDetails getIssueDetails() {
        return issueDetails;
    }

    /**
     * Sets the value of the issueDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link IssueDetails }
     *     
     */
    public void setIssueDetails(IssueDetails value) {
        this.issueDetails = value;
    }

    /**
     * Gets the value of the returnDetails property.
     * 
     * @return
     *     possible object is
     *     {@link ReturnDetails }
     *     
     */
    public ReturnDetails getReturnDetails() {
        return returnDetails;
    }

    /**
     * Sets the value of the returnDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReturnDetails }
     *     
     */
    public void setReturnDetails(ReturnDetails value) {
        this.returnDetails = value;
    }

    /**
     * Gets the value of the invoicingDetails property.
     * 
     * @return
     *     possible object is
     *     {@link InvoicingDetails }
     *     
     */
    public InvoicingDetails getInvoicingDetails() {
        return invoicingDetails;
    }

    /**
     * Sets the value of the invoicingDetails property.
     * 
     * @param value
     *     allowed object is
     *     {@link InvoicingDetails }
     *     
     */
    public void setInvoicingDetails(InvoicingDetails value) {
        this.invoicingDetails = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
